@@ -70,6 +70,9 @@ def get_feedName(irc, msg, args, state):
     if not registry.isValidRegistryName(args[0]):
         state.errorInvalid('feed name', args[0],
                            'Feed names must not include spaces.')
+    if "." in args[0]:
+        state.errorInvalid('feed name', args[0],
+                           'Feed names must not include dots.')
     state.args.append(callbacks.canonicalName(args.pop(0)))
 addConverter('feedName', get_feedName)
 
@@ -183,10 +186,45 @@ def save_announces_db(db, fd):
 
 
 class RSS(callbacks.Plugin):
-    """This plugin is useful both for announcing updates to RSS feeds in a
+    """
+    This plugin is useful both for announcing updates to RSS feeds in a
     channel, and for retrieving the headlines of RSS feeds via command.  Use
     the "add" command to add feeds to this plugin, and use the "announce"
-    command to determine what feeds should be announced in a given channel."""
+    command to determine what feeds should be announced in a given channel.
+
+    Basic usage
+    ^^^^^^^^^^^
+
+    1. Add a feed using
+       ``@rss add limnoria https://github.com/ProgVal/Limnoria/tags.atom``.
+
+       * This is RSS feed of Limnoria's stable releases.
+       * You can now check the latest news from the feed with ``@limnoria``.
+
+    2. To have new news automatically announced on the channel, use
+       ``@rss announce add Limnoria``.
+
+    To add another feed, simply replace limnoria and the address using name
+    of the feed and address of the feed. For example, YLE News:
+
+    1. ``@rss add yle http://yle.fi/uutiset/rss/uutiset.rss?osasto=news``
+    2. ``@rss announce add yle``
+
+    News on their own lines
+    ^^^^^^^^^^^^^^^^^^^^^^^
+
+    If you want the feed topics to be on their own lines instead of being separated by
+    the separator which you have configured you can set `reply.onetoone` to False.
+
+    Please first read the help for that configuration variable
+
+    ``@config help reply.onetoone``
+
+    and understand what it says and then you can do
+
+    ``@config reply.onetoone False``
+
+    """
     threaded = True
     def __init__(self, irc):
         self.__parent = super(RSS, self)
@@ -252,11 +290,17 @@ class RSS(callbacks.Plugin):
         self.feeds[url] = Feed(name, url, initial,
                 plugin_is_loading, announced)
 
-    def remove_feed(self, feed):
-        del self.feed_names[feed.name]
-        del self.feeds[feed.url]
-        conf.supybot.plugins.RSS.feeds().remove(feed.name)
-        conf.supybot.plugins.RSS.feeds.unregister(feed.name)
+    def remove_feed(self, name_or_url):
+        self.feed_names.pop(name_or_url, None)
+        while True:
+            try:
+                conf.supybot.plugins.RSS.feeds().remove(name_or_url)
+            except KeyError:
+                break
+        try:
+            conf.supybot.plugins.RSS.feeds.unregister(name_or_url)
+        except (KeyError, registry.NonExistentRegistryEntry):
+            pass
 
     ##################
     # Methods handling
@@ -376,8 +420,12 @@ class RSS(callbacks.Plugin):
         new_entries = sort_feed_items(new_entries, 'newestFirst')
         for irc in world.ircs:
             for channel in irc.state.channels:
-                if feed.name not in self.registryValue('announce',
-                                                       channel, irc.network):
+                # Old bots have it set in plugins.RSS.announce.#channel,
+                # new bots set it in plugins.RSS.announce.:network.#channel,
+                # so we want to read from both.
+                channel_feeds = self.registryValue('announce', channel) \
+                    | self.registryValue('announce', channel, irc.network)
+                if feed.name not in channel_feeds:
                     continue
                 if initial:
                     max_entries = self.registryValue(
@@ -475,7 +523,17 @@ class RSS(callbacks.Plugin):
         if not feed:
             irc.error(_('That\'s not a valid RSS feed command name.'))
             return
-        self.remove_feed(feed)
+
+        # If the feed was first created "anonymously", eg. with
+        # `@rss announce add http://example.org/rss`, then as a named feed
+        # with `@rss add example http://example.org/rss`,
+        # `self.get_feed(name)` above gets only one of them; so let's
+        # remove the aliased name or URL from the feed names too,
+        # or we would have a dangling entry here.
+        self.remove_feed(feed.url)
+        self.remove_feed(name)
+        assert self.get_feed(name) is None
+
         irc.replySuccess()
     remove = wrap(remove, ['feedName'])
 
@@ -488,7 +546,9 @@ class RSS(callbacks.Plugin):
             only necessary if the message isn't sent in the channel itself.
             """
             announce = conf.supybot.plugins.RSS.announce
-            feeds = format('%L', list(announce.get(channel)()))
+            channel_feeds = announce.getSpecific(channel=channel) \
+                | announce.getSpecific(channel=channel, network=irc.network)
+            feeds = format('%L', set(channel_feeds)) # set() to deduplicate
             irc.reply(feeds or _('I am currently not announcing any feeds.'))
         list = wrap(list, ['channel',])
 
@@ -508,10 +568,10 @@ class RSS(callbacks.Plugin):
                 irc.error(format(_('These feeds are unknown: %L'),
                     invalid_feeds), Raise=True)
             announce = conf.supybot.plugins.RSS.announce
-            S = announce.get(channel)()
+            S = announce.getSpecific(channel=channel, network=irc.network)()
             for name in feeds:
                 S.add(name)
-            announce.get(channel).setValue(S)
+            announce.getSpecific(channel=channel, network=irc.network).setValue(S)
             irc.replySuccess()
             for name in feeds:
                 feed = plugin.get_feed(name)
