@@ -477,6 +477,15 @@ class RichReplyMethods(object):
             channel=self.msg.channel, network=self.irc.network)
 
     def replySuccess(self, s='', **kwargs):
+        r"""Replies with a success message, configurable with
+        ``supybot.replies.success`` or the Success plugin.
+
+        :arg str s:
+            Text to append to the standard success message
+
+        :arg \**kwargs:
+            See :meth:`NestedCommandsIrcProxy.reply`'s keyword arguments
+        """
         v = self._getConfig(conf.supybot.replies.success)
         if v:
             s = self.__makeReply(v, s)
@@ -502,7 +511,10 @@ class RichReplyMethods(object):
         # change the state of this Irc object.
         if to is not None:
             self.to = self.to or to
-        target = self.private and self.to or self.msg.args[0]
+        if self.private or self.msg.channel is None:
+            target = self.msg.nick
+        else:
+            target = self.to or self.msg.args[0]
         return target
 
     def replies(self, L, prefixer=None, joiner=None,
@@ -618,6 +630,7 @@ class ReplyIrcProxy(RichReplyMethods):
     """This class is a thin wrapper around an irclib.Irc object that gives it
     the reply() and error() methods (as well as everything in RichReplyMethods,
     based on those two)."""
+    _mores = ircutils.IrcDict()
     def __init__(self, irc, msg):
         self.irc = irc
         self.msg = msg
@@ -651,24 +664,302 @@ class ReplyIrcProxy(RichReplyMethods):
             self.irc.queueMsg(m)
             return m
 
+    def _defaultPrefixNick(self, msg):
+        if msg.channel:
+            return conf.get(conf.supybot.reply.withNickPrefix,
+                channel=msg.channel, network=self.irc.network)
+        else:
+            return conf.supybot.reply.withNickPrefix()
+
     def reply(self, s, msg=None, **kwargs):
+        """
+        Keyword arguments:
+
+        :arg bool noLengthCheck:
+            True if the length shouldn't be checked (used for 'more' handling)
+
+        :arg bool prefixNick:
+            False if the nick shouldn't be prefixed to the reply.
+
+        :arg bool action:
+            True if the reply should be an action.
+
+        :arg bool private:
+            True if the reply should be in private.
+
+        :arg bool notice:
+            True if the reply should be noticed when the bot is configured
+            to do so.
+
+        :arg str to:
+            The nick or channel the reply should go to.
+            Defaults to msg.args[0] (or msg.nick if private)
+
+        :arg bool sendImmediately:
+            True if the reply should use sendMsg() which
+            bypasses conf.supybot.protocols.irc.throttleTime
+            and gets sent before any queued messages
+        """
         if msg is None:
             msg = self.msg
         assert not isinstance(s, ircmsgs.IrcMsg), \
                'Old code alert: there is no longer a "msg" argument to reply.'
         kwargs.pop('noLengthCheck', None)
-        m = _makeReply(self, msg, s, **kwargs)
-        self.irc.queueMsg(m)
-        return m
+        if 'target' not in kwargs:
+            # TODO: deduplicate this with _getTarget
+            # TODO: it looks like 'target' is never in kwargs.
+            #       (an old version of this code crashed when 'target' was
+            #       not given, but no one complained). Remove the conditional?
+            if kwargs.get('private', False) or msg.channel is None:
+                kwargs['target'] = msg.nick
+            else:
+                kwargs['target'] = kwargs.get('to', None) or msg.args[0]
+        if 'prefixNick' not in kwargs:
+            kwargs['prefixNick'] = self._defaultPrefixNick(msg)
+        self._sendReply(s, msg=msg, **kwargs)
 
     def __getattr__(self, attr):
         return getattr(self.irc, attr)
 
+    def _replyOverhead(self, target, targetNick, prefixNick):
+        """Returns the number of bytes added to a PRIVMSG payload, either by
+        Limnoria itself or by the server.
+        Ignores tag bytes, as they are accounted for separatly."""
+        overhead = (
+            len(':')
+            + len(self.irc.prefix.encode())
+            + len(' PRIVMSG ')
+            + len(target.encode())
+            + len(' :')
+            + len('\r\n')
+        )
+        if prefixNick and targetNick is not None:
+            overhead += len(targetNick) + len(': ')
+        return overhead
+
+    def _sendReply(self, s, target, msg, sendImmediately=False,
+                   noLengthCheck=False, **kwargs):
+        if sendImmediately:
+            sendMsg = self.irc.sendMsg
+        else:
+            sendMsg = self.irc.queueMsg
+
+        if isinstance(self.irc, self.__class__):
+            s = s[:conf.supybot.reply.maximumLength()]
+            return self.irc.reply(s,
+                                  noLengthCheck=noLengthCheck,
+                                  **kwargs)
+        elif noLengthCheck:
+            # noLengthCheck only matters to NestedCommandsIrcProxy, so
+            # it's not used here.  Just in case you were wondering.
+            m = _makeReply(self, msg, s, **kwargs)
+            sendMsg(m)
+            return m
+        else:
+            s = ircutils.safeArgument(s)
+            allowedLength = conf.get(conf.supybot.reply.mores.length,
+                channel=target, network=self.irc.network)
+            if not allowedLength: # 0 indicates this.
+                allowedLength = 512 - self._replyOverhead(
+                        target, msg.nick, prefixNick=kwargs['prefixNick'])
+            maximumMores = conf.get(conf.supybot.reply.mores.maximum,
+                channel=target, network=self.irc.network)
+            maximumLength = allowedLength * maximumMores
+            if len(s) > maximumLength:
+                log.warning('Truncating to %s bytes from %s bytes.',
+                            maximumLength, len(s))
+                s = s[:maximumLength]
+            s_size = len(s.encode()) if minisix.PY3 else len(s)
+            if s_size <= allowedLength or \
+               not conf.get(conf.supybot.reply.mores,
+                    channel=target, network=self.irc.network):
+                # There's no need for action=self.action here because
+                # action implies noLengthCheck, which has already been
+                # handled.  Let's stick an assert in here just in case.
+                assert not kwargs.get('action')
+                m = _makeReply(self, msg, s, **kwargs)
+                sendMsg(m)
+                return m
+            # The '(XX more messages)' may have not the same
+            # length in the current locale
+            allowedLength -= len(_('(XX more messages)')) + 1 # bold
+            chunks = ircutils.wrap(s, allowedLength)
+
+            # Last messages to display at the beginning of the list
+            # (which is used like a stack)
+            chunks.reverse()
+
+            instant = conf.get(conf.supybot.reply.mores.instant,
+                channel=target, network=self.irc.network)
+
+            # Big complex loop ahead, with lots of cases and opportunities for
+            # off-by-one errors. Here is the meaning of each of the variables
+            #
+            # * 'i' is the number of chunks after the current one
+            #
+            # * 'is_first' is True when the message is the very first message
+            #   (so last iteration of the loop)
+            #
+            # * 'is_last' is True when the message is the very last (so first
+            #   iteration of the loop)
+            #
+            # * 'is_instant' is True when the message is in one of the messages
+            #   sent immediately when the command is called, ie. without
+            #   calling @misc more. (when supybot.reply.mores.instant is 1,
+            #   which is the default, this is equivalent to 'is_first')
+            #
+            # * 'is_last_instant' is True when the message is the last of the
+            #   instant message (so the first iteration of the loop with an
+            #   instant message).
+            #
+            # We need all this complexity because pagination is hard, and we
+            # want:
+            #
+            # * the '(XX more messages)' suffix on the last instant message,
+            #   and every other message (mandatory, it's a great feature),
+            #   but not on the other instant messages (mandatory when
+            #   multiline is enabled, but very nice to have in general)
+            # * the nick prefix on the first message and every other message
+            #   that isn't instant (mandatory), but not on the other instant
+            #   messages (also mandatory only when multiline is enabled)
+            msgs = []
+            for (i, chunk) in enumerate(chunks):
+                is_first = i == len(chunks) - 1
+                is_last = i == 0
+                is_instant = len(chunks) - i <= instant
+                is_last_instant = len(chunks) - i == instant
+                if is_last:
+                    # last message, no suffix to add
+                    pass
+                elif is_instant and not is_last_instant:
+                    # one of the first messages, and the next one will
+                    # also be sent immediately, so no suffix
+                    pass
+                else:
+                    if i == 1:
+                        more = _('more message')
+                    else:
+                        more = _('more messages')
+                    n = ircutils.bold('(%i %s)' % (len(msgs), more))
+                    chunk = '%s %s' % (chunk, n)
+
+                if is_instant and not is_first:
+                    d = kwargs.copy()
+                    d['prefixNick'] = False
+                    msgs.append(_makeReply(self, msg, chunk, **d))
+                else:
+                    msgs.append(_makeReply(self, msg, chunk, **kwargs))
+
+            instant_messages = []
+
+            while instant > 0 and msgs:
+                instant -= 1
+                response = msgs.pop()
+                instant_messages.append(response)
+                # XXX We should somehow allow these to be returned, but
+                #     until someone complains, we'll be fine :)  We
+                #     can't return from here, though, for obvious
+                #     reasons.
+                # return m
+
+            if conf.supybot.protocols.irc.experimentalExtensions() \
+                    and 'draft/multiline' in self.state.capabilities_ack \
+                    and len(instant_messages) > 1:
+                # More than one message to send now, and we are allowed to use
+                # multiline batches, so let's do it
+                self.queueMultilineBatches(
+                    instant_messages, target, msg.nick, concat=True,
+                    allowedLength=allowedLength, sendImmediately=sendImmediately)
+            else:
+                for instant_msg in instant_messages:
+                    sendMsg(instant_msg)
+
+            if not msgs:
+                return
+            prefix = msg.prefix
+            if target and ircutils.isNick(target):
+                try:
+                    state = self.getRealIrc().state
+                    prefix = state.nickToHostmask(target)
+                except KeyError:
+                    pass # We'll leave it as it is.
+            if '!' in prefix and '@' in prefix:
+                mask = prefix.split('!', 1)[1]
+                self._mores[mask] = msgs
+            public = bool(self.msg.channel)
+            private = kwargs.get('private', False) or not public
+            self._mores[msg.nick] = (private, msgs)
+            return response
+
+    def queueMultilineBatches(self, msgs, target, targetNick, concat,
+                              allowedLength=0, sendImmediately=False):
+        """Queues the msgs passed as argument in batches using draft/multiline
+        batches.
+
+        This errors if experimentalExtensions is disabled or draft/multiline
+        was not negotiated."""
+        assert conf.supybot.protocols.irc.experimentalExtensions()
+        assert 'draft/multiline' in self.state.capabilities_ack
+
+        if not allowedLength: # 0 indicates this.
+            # We're only interested in the overhead outside the payload,
+            # regardless of the entire payload (nick prefix included),
+            # so prefixNick=False
+            allowedLength = 512 - self._replyOverhead(
+                    target, targetNick, prefixNick=False)
+
+        multiline_cap_values = ircutils.parseCapabilityKeyValue(
+            self.state.capabilities_ls['draft/multiline'])
+
+        # All the messages in instant_messages are to be sent
+        # immediately, in multiline batches.
+        max_bytes_per_batch = int(multiline_cap_values['max-bytes'])
+
+        # We have to honor max_bytes_per_batch, but I don't want to
+        # encode messages again here just to have their length, so
+        # let's assume they all have the maximum length.
+        # It's not optimal, but close enough and simplifies the code.
+        messages_per_batch = max_bytes_per_batch // allowedLength
+
+        # "Clients MUST NOT send tags other than draft/multiline-concat and
+        # batch on messages within the batch. In particular, all client-only
+        # tags associated with the message must be sent attached to the initial
+        # BATCH command."
+        # -- <https://ircv3.net/specs/extensions/multiline>
+        # So we copy the tags of the first message, discard the tags of all
+        # other messages, and apply the tags to the opening BATCH
+        server_tags = msgs[0].server_tags
+
+        for batch_msgs in utils.iter.grouper(msgs, messages_per_batch):
+            # TODO: should use sendBatch instead of queueBatch if
+            # sendImmediately is True
+            batch_name = ircutils.makeLabel()
+            batch = []
+            batch.append(ircmsgs.IrcMsg(command='BATCH',
+                args=('+' + batch_name, 'draft/multiline', target),
+                server_tags=server_tags))
+
+            for (i, batch_msg) in enumerate(batch_msgs):
+                if batch_msg is None:
+                    continue  # 'grouper' generates None at the end
+                assert 'batch' not in batch_msg.server_tags
+
+                # Discard the existing tags, and add the batch ones.
+                batch_msg.server_tags = {'batch': batch_name}
+                if concat and i > 0:
+                    # Tell clients not to add a newline after this
+                    batch_msg.server_tags['draft/multiline-concat'] = None
+                batch.append(batch_msg)
+
+            batch.append(ircmsgs.IrcMsg(
+                command='BATCH', args=('-' + batch_name,)))
+
+            self.queueBatch(batch)
+
 SimpleProxy = ReplyIrcProxy # Backwards-compatibility
 
 class NestedCommandsIrcProxy(ReplyIrcProxy):
     "A proxy object to allow proper nesting of commands (even threaded ones)."
-    _mores = ircutils.IrcDict()
     def __init__(self, irc, msg, args, nested=0):
         assert isinstance(args, list), 'Args should be a list, not a string.'
         super(NestedCommandsIrcProxy, self).__init__(irc, msg)
@@ -712,11 +1003,7 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
         self.notice = None
         self.private = None
         self.noLengthCheck = None
-        if self.msg.channel:
-            self.prefixNick = conf.get(conf.supybot.reply.withNickPrefix,
-                channel=self.msg.channel, network=self.irc.network)
-        else:
-            self.prefixNick = conf.supybot.reply.withNickPrefix()
+        self.prefixNick = self._defaultPrefixNick(self.msg)
 
     def evalArgs(self, withClass=None):
         while self.counter < len(self.args):
@@ -891,33 +1178,12 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
     def reply(self, s, noLengthCheck=False, prefixNick=None, action=None,
               private=None, notice=None, to=None, msg=None,
               sendImmediately=False, stripCtcp=True):
-        """
-        Keyword arguments:
-
-        * `noLengthCheck=False`:   True if the length shouldn't be checked
-                                   (used for 'more' handling)
-        * `prefixNick=True`:       False if the nick shouldn't be prefixed to the
-                                   reply.
-        * `action=False`:          True if the reply should be an action.
-        * `private=False`:         True if the reply should be in private.
-        * `notice=False`:          True if the reply should be noticed when the
-                                   bot is configured to do so.
-        * `to=<nick|channel>`:     The nick or channel the reply should go to.
-                                   Defaults to msg.args[0] (or msg.nick if private)
-        * `sendImmediately=False`: True if the reply should use sendMsg() which
-                                   bypasses conf.supybot.protocols.irc.throttleTime
-                                   and gets sent before any queued messages
-        """
         # These use and or or based on whether or not they default to True or
         # False.  Those that default to True use and; those that default to
         # False use or.
         assert not isinstance(s, ircmsgs.IrcMsg), \
                'Old code alert: there is no longer a "msg" argument to reply.'
         self.repliedTo = True
-        if sendImmediately:
-            sendMsg = self.irc.sendMsg
-        else:
-            sendMsg = self.irc.queueMsg
         if msg is None:
             msg = self.msg
         if prefixNick is not None:
@@ -926,6 +1192,7 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
             self.action = self.action or action
             if action:
                 self.prefixNick = False
+                self.noLengthCheck = True
         if notice is not None:
             self.notice = self.notice or notice
         if private is not None:
@@ -936,115 +1203,22 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
         if not isinstance(s, minisix.string_types): # avoid trying to str() unicode
             s = str(s) # Allow non-string esses.
 
-        replyArgs = dict(
-            to=self.to,
-            notice=self.notice,
-            action=self.action,
-            private=self.private,
-            prefixNick=self.prefixNick,
-            stripCtcp=stripCtcp
-        )
-
         if self.finalEvaled:
             try:
-                if isinstance(self.irc, self.__class__):
-                    s = s[:conf.supybot.reply.maximumLength()]
-                    return self.irc.reply(s,
-                                          noLengthCheck=self.noLengthCheck,
-                                          **replyArgs)
-                elif self.noLengthCheck:
-                    # noLengthCheck only matters to NestedCommandsIrcProxy, so
-                    # it's not used here.  Just in case you were wondering.
-                    m = _makeReply(self, msg, s, **replyArgs)
-                    sendMsg(m)
-                    return m
-                else:
-                    s = ircutils.safeArgument(s)
-                    allowedLength = conf.get(conf.supybot.reply.mores.length,
-                        channel=target, network=self.irc.network)
-                    if not allowedLength: # 0 indicates this.
-                        allowedLength = (512
-                                - len(':') - len(self.irc.prefix)
-                                - len(' PRIVMSG ')
-                                - len(target)
-                                - len(' :')
-                                - len('\r\n')
-                                )
-                        if self.prefixNick:
-                            allowedLength -= len(msg.nick) + len(': ')
-                    maximumMores = conf.get(conf.supybot.reply.mores.maximum,
-                        channel=target, network=self.irc.network)
-                    maximumLength = allowedLength * maximumMores
-                    if len(s) > maximumLength:
-                        log.warning('Truncating to %s bytes from %s bytes.',
-                                    maximumLength, len(s))
-                        s = s[:maximumLength]
-                    s_size = len(s.encode()) if minisix.PY3 else len(s)
-                    if s_size <= allowedLength or \
-                       not conf.get(conf.supybot.reply.mores,
-                            channel=target, network=self.irc.network):
-                        # There's no need for action=self.action here because
-                        # action implies noLengthCheck, which has already been
-                        # handled.  Let's stick an assert in here just in case.
-                        assert not self.action
-                        m = _makeReply(self, msg, s, **replyArgs)
-                        sendMsg(m)
-                        return m
-                    # The '(XX more messages)' may have not the same
-                    # length in the current locale
-                    allowedLength -= len(_('(XX more messages)')) + 1 # bold
-                    chunks = ircutils.wrap(s, allowedLength)
-
-                    # Last messages to display at the beginning of the list
-                    # (which is used like a stack)
-                    chunks.reverse()
-
-                    instant = conf.get(conf.supybot.reply.mores.instant,
-                        channel=target, network=self.irc.network)
-
-                    msgs = []
-                    for (i, chunk) in enumerate(chunks):
-                        if i == 0:
-                            pass # last message, no suffix to add
-                        elif len(chunks) - i < instant:
-                            # one of the first messages, and the next one will
-                            # also be sent immediately, so no suffix
-                            pass
-                        else:
-                            if i == 1:
-                                more = _('more message')
-                            else:
-                                more = _('more messages')
-                            n = ircutils.bold('(%i %s)' % (len(msgs), more))
-                            chunk = '%s %s' % (chunk, n)
-                        msgs.append(_makeReply(self, msg, chunk, **replyArgs))
-
-                    while instant > 1 and msgs:
-                        instant -= 1
-                        response = msgs.pop()
-                        sendMsg(response)
-                        # XXX We should somehow allow these to be returned, but
-                        #     until someone complains, we'll be fine :)  We
-                        #     can't return from here, though, for obvious
-                        #     reasons.
-                        # return m
-                    if not msgs:
-                        return
-                    response = msgs.pop()
-                    prefix = msg.prefix
-                    if self.to and ircutils.isNick(self.to):
-                        try:
-                            state = self.getRealIrc().state
-                            prefix = state.nickToHostmask(self.to)
-                        except KeyError:
-                            pass # We'll leave it as it is.
-                    mask = prefix.split('!', 1)[1]
-                    self._mores[mask] = msgs
-                    public = bool(self.msg.channel)
-                    private = self.private or not public
-                    self._mores[msg.nick] = (private, msgs)
-                    sendMsg(response)
-                    return response
+                self._sendReply(
+                    s=s, target=target, msg=msg,
+                    to=self.to,
+                    notice=self.notice,
+                    action=self.action,
+                    private=self.private,
+                    prefixNick=self.prefixNick,
+                    stripCtcp=stripCtcp,
+                    noLengthCheck=self.noLengthCheck,
+                    sendImmediately=sendImmediately,
+                )
+            except:
+                log.exception('Error while sending reply')
+                raise
             finally:
                 self._resetReplyAttributes()
         else:
@@ -1083,6 +1257,18 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                 oneToOne=oneToOne, **kwargs)
 
     def error(self, s='', Raise=False, **kwargs):
+        r"""Replies with an error.
+
+        :arg str s:
+            The error message
+
+        :arg bool Raise:
+            If True, this will raise :class:`Error` that will propagate so
+            that the caller of this function immediately terminates
+
+        :arg \**kwargs:
+            See :meth:`NestedCommandsIrcProxy.reply`'s keyword arguments
+        """
         self.repliedTo = True
         if Raise:
             raise Error(s)
@@ -1237,16 +1423,22 @@ class Commands(BasePlugin, SynchronizedAndFirewalled):
     _disabled = DisabledCommands()
     pre_command_callbacks = []
     def name(self):
+        """Returns the name of this Commands object (usually the plugin
+        name)."""
         return self.__class__.__name__
 
     def canonicalName(self):
+        """Same as :py:meth:`name`, but normalized."""
         return canonicalName(self.name())
 
     def isDisabled(self, command):
+        """Returns whether the given ``command`` is disabled."""
         return self._disabled.disabled(command, self.name())
 
     def isCommandMethod(self, name):
-        """Returns whether a given method name is a command in this plugin."""
+        """Returns whether a given method name is a command in this plugin.
+        Plugins only need to implement this if they have a dynamic set of
+        commands."""
         # This function is ugly, but I don't want users to call methods like
         # doPrivmsg or __init__ or whatever, and this is good to stop them.
 
@@ -1277,6 +1469,9 @@ class Commands(BasePlugin, SynchronizedAndFirewalled):
             return self.getCommand(command) == command
 
     def getCommand(self, args, stripOwnName=True):
+        """Among all the commands in this Commands object, recursively
+        searches for the command whose name is the longst substring
+        of ``args``, and returns its name, splitted on spaces."""
         assert args == list(map(canonicalName, args))
         first = args[0]
         for cb in self.cbs:
@@ -1292,7 +1487,10 @@ class Commands(BasePlugin, SynchronizedAndFirewalled):
         return []
 
     def getCommandMethod(self, command):
-        """Gets the given command from this plugin."""
+        """Gets the given command from this plugin, using
+        :py:meth:`getCommand`.
+        Plugins only need to implement this if they have a dynamic set of
+        commands."""
         #print '*** %s.getCommandMethod(%r)' % (self.name(), command)
         assert not isinstance(command, minisix.string_types)
         assert command == list(map(canonicalName, command))
@@ -1313,6 +1511,9 @@ class Commands(BasePlugin, SynchronizedAndFirewalled):
                     raise AttributeError
 
     def listCommands(self, pluginCommands=[]):
+        """List all the commands in this ``Commands`` object.
+        Plugins only need to implement this if they have a dynamic set of
+        commands."""
         commands = set(pluginCommands)
         for s in dir(self):
             if self.isCommandMethod(s):
@@ -1329,6 +1530,8 @@ class Commands(BasePlugin, SynchronizedAndFirewalled):
         return L
 
     def callCommand(self, command, irc, msg, *args, **kwargs):
+        """Given a command name, gets the method with
+        :py:meth:`getCommandMethod` and calls it."""
         # We run all callbacks before checking if one of them returned True
         if any(bool, list(cb(self, command, irc, msg, *args, **kwargs)
                     for cb in self.pre_command_callbacks)):
@@ -1394,6 +1597,8 @@ class Commands(BasePlugin, SynchronizedAndFirewalled):
                 irc.replyError(msg=msg)
 
     def getCommandHelp(self, command, simpleSyntax=None):
+        """Returns the help string of the given command, using
+        :py:meth:`getCommandMethod`."""
         method = self.getCommandMethod(command)
         help = getHelp
         chan = None
@@ -1449,6 +1654,16 @@ class PluginMixin(BasePlugin, irclib.IrcCallback):
             self.__parent.__call__(irc, msg)
 
     def registryValue(self, name, channel=None, network=None, *, value=True):
+        """Returns the value of a configuration variable specified by
+        ``name``.
+
+        If the configuration variable has a channel- or network-specific
+        variable (ie. if its value can change across channels or networks),
+        ``channel`` and ``network`` allow getting the most specific value.
+        If neither is given, returns the generic value.
+
+        If ``value=False``, returns the variable itself (an instance
+        of :py:class:`supybot.registry.Value`) instead of its value."""
         if isinstance(network, bool):
             # Network-unaware plugin that uses 'value' as a positional
             # argument.
@@ -1466,6 +1681,7 @@ class PluginMixin(BasePlugin, irclib.IrcCallback):
             return group
 
     def setRegistryValue(self, name, value, channel=None, network=None):
+        """Sets a configuration variable. See :py:meth:`registryValue`"""
         plugin = self.name()
         group = conf.supybot.plugins.get(plugin)
         names = registry.split(name)
