@@ -42,11 +42,7 @@ import threading
 import select
 import socket
 
-try:
-    import ipaddress  # Python >= 3.3 or backported ipaddress
-except ImportError:
-    # Python < 3.3
-    ipaddress = None
+import ipaddress
 
 from .. import (conf, drivers, log, utils, world)
 from ..utils import minisix
@@ -269,6 +265,11 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
             log.error('Cannot use socks proxy (SocksiPy not installed), '
                     'using direct connection instead.')
             socks_proxy = ''
+        if socks_proxy:
+            # Do not try to resolve, let the SOCKS proxy do it.
+            # (Avoids leaking DNS queries *and* is necessary for onion
+            # services)
+            address = self.currentServer.hostname
         else:
             try:
                 address = utils.net.getAddressFromHostname(
@@ -278,7 +279,7 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
                 drivers.log.connectError(self.currentServer, e)
                 self.scheduleReconnect()
                 return
-        drivers.log.connect(self.currentServer)
+        drivers.log.connect(self.currentServer, socks_proxy=socks_proxy)
         try:
             self.conn = utils.net.getSocket(
                     address,
@@ -309,21 +310,30 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
                 address = address.decode('utf-8')
             elif (not network_config.requireStarttls()) and \
                     (not network_config.ssl()) and \
-                    (not self.currentServer.force_tls_verification) and \
-                    (ipaddress is None or not ipaddress.ip_address(address).is_loopback):
-                drivers.log.warning(('Connection to network %s '
-                    'does not use SSL/TLS, which makes it vulnerable to '
-                    'man-in-the-middle attacks and passive eavesdropping. '
-                    'You should consider upgrading your connection to SSL/TLS '
-                    '<http://docs.limnoria.net/en/latest/use/faq.html#how-to-make-a-connection-secure>')
-                    % self.irc.network)
+                    (not self.currentServer.force_tls_verification):
+
+                try:
+                    is_loopback = ipaddress.ip_address(address).is_loopback
+                except ValueError:
+                    # address is a hostname, eg. because we're using a SOCKS
+                    # proxy
+                    is_loopback = False
+                if not is_loopback:
+                    drivers.log.warning(('Connection to network %s '
+                        'does not use SSL/TLS, which makes it vulnerable to '
+                        'man-in-the-middle attacks and passive eavesdropping. '
+                        'You should consider upgrading your connection to SSL/TLS '
+                        '<http://docs.limnoria.net/en/latest/use/faq.html#how-to-make-a-connection-secure>')
+                        % self.irc.network)
 
             conf.supybot.drivers.poll.addCallback(self.setTimeout)
             self.setTimeout()
             self.connected = True
             self.resetDelay()
         except socket.error as e:
-            if e.args[0] == 115:
+            if len(e.args) >= 1 and e.args[0] == 115:
+                # e.args may be () in some circumstances,
+                # eg. when e is an instance of socks.GeneralProxyError
                 now = time.time()
                 when = now + 60
                 whenS = log.timestamp(when)
