@@ -268,7 +268,8 @@ class SupyHTTPServerCallback(log.Firewalled):
     def doHead(self, handler, path):
         self.doGetOrHead(handler, path, write_content=False)
 
-    doPost = doGet
+    def doPost(self, handler, path, form=None):
+        self.doGetOrHead(handler, path, write_content=True)
 
     def doWellKnown(self, handler, path):
         """Handles GET request to /.well-known/"""
@@ -399,6 +400,7 @@ class SupyWellKnown(SupyHTTPServerCallback):
 
         handler.send_response(404)
         self.end_headers()
+        self.wfile.write(b"Error 404. There is nothing to see here.")
 
 
 DEFAULT_CALLBACKS = {'.well-known': SupyWellKnown()}
@@ -446,12 +448,13 @@ class RealSupyHTTPServer(HTTPServer):
 class TestSupyHTTPServer(RealSupyHTTPServer):
     def __init__(self, *args, **kwargs):
         self.callbacks = {}
+        self.server_address = ("0.0.0.0", 0)
     def serve_forever(self, *args, **kwargs):
         pass
     def shutdown(self, *args, **kwargs):
         pass
 
-if world.testing:
+if world.testing or world.documenting:
     SupyHTTPServer = TestSupyHTTPServer
 else:
     SupyHTTPServer = RealSupyHTTPServer
@@ -468,7 +471,24 @@ def startServer():
             for x in configGroup.hosts6() if x != '']
     http_servers = []
     for protocol, address in (addresses4 + addresses6):
-        server = SupyHTTPServer(address, protocol, SupyHTTPRequestHandler)
+        try:
+            server = SupyHTTPServer(address, protocol, SupyHTTPRequestHandler)
+        except OSError as e:
+            log.error(
+                'Failed to start HTTP server with protocol %s at address: %s',
+                protocol, address, e)
+            if e.args[0] == 98:
+                log.error(
+                    'This means the port (and address) is already in use by an '
+                    'other process. Either find the process using the port '
+                    'and stop it, or change the port configured in '
+                    'supybot.servers.http.port.')
+            continue
+        except:
+            log.exception(
+                "Failed to start HTTP server with protocol %s at address",
+                protocol, address)
+            continue
         Thread(target=server.serve_forever, name='HTTP Server').start()
         http_servers.append(server)
         log.info('Starting HTTP server: %s' % str(server))
