@@ -218,7 +218,8 @@ class IrcUser(object):
         else:
             self.hostmasks = hostmasks
         if nicks is None:
-            self.nicks = {} # {'network1': ['foo', 'bar'], 'network': ['baz']}
+            # {'network1': ['foo', 'bar'], 'network': ['baz']}
+            self.nicks = ircutils.IrcDict()
         else:
             self.nicks = nicks
         self.gpgkeys = [] # GPG key ids
@@ -251,16 +252,19 @@ class IrcUser(object):
             return self.capabilities.check(capability, ignoreOwner=ignoreOwner)
 
     def setPassword(self, password, hashed=False):
-        """Sets the user's password."""
+        """Sets the user's password. If password is None, it will be disabled."""
         if hashed or self.hashed:
             self.hashed = True
-            self.password = utils.saltHash(password)
+            if password is None:
+                self.password = ""
+            else:
+                self.password = utils.saltHash(password)
         else:
             self.password = password
 
     def checkPassword(self, password):
         """Checks the user's password."""
-        if password is None:
+        if password is None or not self.password:
             return False
         if self.hashed:
             (salt, _) = self.password.split('|')
