@@ -1430,7 +1430,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
         if self.fastqueue:
             msg = self.fastqueue.dequeue()
         elif self.queue:
-            if now-self.lastTake <= conf.supybot.protocols.irc.throttleTime():
+            if now-self.lastTake < conf.supybot.protocols.irc.throttleTime():
                 log.debug('Irc.takeMsg throttling.')
             else:
                 self.lastTake = now
@@ -1564,7 +1564,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
         received* tags."""
         if tag:
             self._tagMsg(msg)
-        channel = msg.channel
+        channel = msg.channel  # used by dynamicScope (ew)
 
         preInFilter = str(msg).rstrip('\r\n')
         log.debug('Incoming message (%s): %s', self.network, preInFilter)
@@ -1973,7 +1973,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
 
     def do906(self, msg):
         log.warning('%s: SASL authentication aborted', self.network)
-        self.tryNextSaslMechanism(msg)
+        self.tryNextSaslMechanism(msg)  # TODO: should not try this in state INIT_WAITING_MOTD (set when sending CAP END because of exhausted list of SASL mechs)
 
     def do907(self, msg):
         log.warning('%s: Attempted SASL authentication when we were already '
